@@ -12,6 +12,7 @@ from dagster import (
     MarkdownMetadataValue,
     MetadataEntry,
     NotebookMetadataValue,
+    NullMetadataValue,
     PathMetadataValue,
     PythonArtifactMetadataValue,
     TableMetadataValue,
@@ -39,6 +40,7 @@ def iterate_metadata_entries(metadata_entries: Sequence[MetadataEntry]) -> Itera
         GrapheneJsonMetadataEntry,
         GrapheneMarkdownMetadataEntry,
         GrapheneNotebookMetadataEntry,
+        GrapheneNullMetadataEntry,
         GraphenePathMetadataEntry,
         GraphenePipelineRunMetadataEntry,
         GraphenePythonArtifactMetadataEntry,
@@ -127,6 +129,11 @@ def iterate_metadata_entries(metadata_entries: Sequence[MetadataEntry]) -> Itera
                 description=metadata_entry.description,
                 boolValue=metadata_entry.entry_data.value,
             )
+        elif isinstance(metadata_entry.entry_data, NullMetadataValue):
+            yield GrapheneNullMetadataEntry(
+                label=metadata_entry.label,
+                description=metadata_entry.description,
+            )
         elif isinstance(metadata_entry.entry_data, DagsterPipelineRunMetadataValue):
             yield GraphenePipelineRunMetadataEntry(
                 label=metadata_entry.label,
