@@ -1,15 +1,20 @@
 from typing import TYPE_CHECKING, cast
 
-from graphene import ResolveInfo
-
 import dagster._check as check
 from dagster._core.execution.plan.resume_retry import ReexecutionStrategy
 from dagster._core.host_representation.selector import PipelineSelector
 from dagster._core.instance import DagsterInstance
 from dagster._core.storage.pipeline_run import DagsterRun, RunsFilter
+from dagster._core.workspace.permissions import Permissions
+from graphene import ResolveInfo
 
 from ..external import get_external_pipeline_or_raise
-from ..utils import ExecutionMetadata, ExecutionParams, capture_error
+from ..utils import (
+    ExecutionMetadata,
+    ExecutionParams,
+    assert_permission_for_location,
+    capture_error,
+)
 from .run_lifecycle import create_valid_pipeline_run
 
 if TYPE_CHECKING:
@@ -75,7 +80,7 @@ def launch_reexecution_from_parent_run(
     graphene_info: "HasContext", parent_run_id: str, strategy: str
 ) -> "GrapheneLaunchRunSuccess":
     """
-    Launch a re-execution by referencing the parent run id
+    Launch a re-execution by referencing the parent run id.
     """
     from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.runs import GrapheneLaunchRunSuccess
@@ -95,14 +100,20 @@ def launch_reexecution_from_parent_run(
         solid_selection=None,
     )
 
+    assert_permission_for_location(
+        graphene_info,
+        Permissions.LAUNCH_PIPELINE_REEXECUTION,
+        selector.location_name,
+    )
+
     repo_location = graphene_info.context.get_repository_location(selector.location_name)
     external_pipeline = get_external_pipeline_or_raise(graphene_info, selector)
 
     run = instance.create_reexecuted_run(
-        cast(DagsterRun, parent_run),
-        repo_location,
-        external_pipeline,
-        ReexecutionStrategy(strategy),
+        parent_run=cast(DagsterRun, parent_run),
+        repo_location=repo_location,
+        external_pipeline=external_pipeline,
+        strategy=ReexecutionStrategy(strategy),
         use_parent_run_tags=True,  # inherit whatever tags were set on the parent run at launch time
     )
     graphene_info.context.instance.submit_run(
