@@ -3,8 +3,6 @@ from __future__ import annotations
 import sys
 from typing import TYPE_CHECKING, Mapping, Optional, Sequence, Union
 
-from graphene import ResolveInfo
-
 import dagster._check as check
 from dagster._config import validate_config_from_snap
 from dagster._core.execution.plan.state import KnownExecutionState
@@ -12,6 +10,7 @@ from dagster._core.host_representation import ExternalPipeline, PipelineSelector
 from dagster._core.host_representation.external import ExternalExecutionPlan
 from dagster._core.workspace.context import BaseWorkspaceRequestContext, WorkspaceRequestContext
 from dagster._utils.error import serializable_error_info_from_exc_info
+from graphene import ResolveInfo
 
 from .utils import UserFacingGraphQLError, capture_error
 
@@ -27,7 +26,7 @@ if TYPE_CHECKING:
 
 
 def get_full_external_pipeline_or_raise(
-    graphene_info: HasContext,
+    graphene_info: "HasContext",
     selector: PipelineSelector,
 ) -> ExternalPipeline:
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
@@ -36,7 +35,7 @@ def get_full_external_pipeline_or_raise(
 
 
 def get_external_pipeline_or_raise(
-    graphene_info: HasContext, selector: PipelineSelector
+    graphene_info: "HasContext", selector: PipelineSelector
 ) -> ExternalPipeline:
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(selector, "selector", PipelineSelector)
@@ -44,7 +43,7 @@ def get_external_pipeline_or_raise(
 
 
 def _get_external_pipeline_or_raise(
-    graphene_info: HasContext, selector: PipelineSelector, ignore_subset: bool = False
+    graphene_info: "HasContext", selector: PipelineSelector, ignore_subset: bool = False
 ) -> ExternalPipeline:
     from ..schema.errors import GrapheneInvalidSubsetError, GraphenePipelineNotFoundError
     from ..schema.pipelines.pipeline import GraphenePipeline
@@ -91,7 +90,6 @@ def ensure_valid_config(
     )
 
     if not validated_config.success:
-
         raise UserFacingGraphQLError(
             GrapheneRunConfigValidationInvalid.for_validation_errors(
                 external_pipeline, validated_config.errors
@@ -102,14 +100,13 @@ def ensure_valid_config(
 
 
 def get_external_execution_plan_or_raise(
-    graphene_info: HasContext,
+    graphene_info: "HasContext",
     external_pipeline: ExternalPipeline,
     mode: Optional[str],
     run_config: Mapping[str, object],
     step_keys_to_execute: Optional[Sequence[str]],
     known_state: Optional[KnownExecutionState],
 ) -> ExternalExecutionPlan:
-
     return graphene_info.context.get_external_execution_plan(
         external_pipeline=external_pipeline,
         run_config=run_config,
@@ -120,7 +117,7 @@ def get_external_execution_plan_or_raise(
 
 
 @capture_error
-def fetch_repositories(graphene_info: HasContext) -> GrapheneRepositoryConnection:
+def fetch_repositories(graphene_info: "HasContext") -> GrapheneRepositoryConnection:
     from ..schema.external import GrapheneRepository, GrapheneRepositoryConnection
 
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
@@ -139,7 +136,7 @@ def fetch_repositories(graphene_info: HasContext) -> GrapheneRepositoryConnectio
 
 @capture_error
 def fetch_repository(
-    graphene_info: HasContext, repository_selector: RepositorySelector
+    graphene_info: "HasContext", repository_selector: RepositorySelector
 ) -> Union[GrapheneRepository, GrapheneRepositoryNotFoundError]:
     from ..schema.errors import GrapheneRepositoryNotFoundError
     from ..schema.external import GrapheneRepository
