@@ -2,14 +2,13 @@ import datetime
 from collections import defaultdict
 from typing import TYPE_CHECKING, Dict, Iterator, List, Mapping, Optional, Sequence, Tuple
 
-from dagster_graphql.implementation.loader import (
-    CrossRepoAssetDependedByLoader,
-    ProjectedLogicalVersionLoader,
-)
-
 import dagster._seven as seven
-from dagster import AssetKey, DagsterEventType, EventRecordsFilter
-from dagster import _check as check
+from dagster import (
+    AssetKey,
+    DagsterEventType,
+    EventRecordsFilter,
+    _check as check,
+)
 from dagster._core.definitions.asset_graph import AssetGraph
 from dagster._core.definitions.freshness_policy import FreshnessPolicy
 from dagster._core.events import ASSET_EVENTS
@@ -22,6 +21,14 @@ from dagster._core.host_representation.repository_location import RepositoryLoca
 from dagster._core.storage.tags import get_dimension_from_partition_tag
 from dagster._utils.caching_instance_queryer import CachingInstanceQueryer
 
+from dagster_graphql.implementation.loader import (
+    CrossRepoAssetDependedByLoader,
+    ProjectedLogicalVersionLoader,
+)
+
+if TYPE_CHECKING:
+    pass
+
 from .utils import capture_error
 
 if TYPE_CHECKING:
@@ -128,7 +135,6 @@ def get_asset_nodes_by_asset_key(graphene_info) -> Mapping[AssetKey, "GrapheneAs
     If multiple repositories have asset nodes for the same asset key, chooses the asset node that
     has an op.
     """
-
     from ..schema.asset_graph import GrapheneAssetNode
 
     depended_by_loader = CrossRepoAssetDependedByLoader(context=graphene_info.context)
@@ -422,7 +428,7 @@ def unique_repos(external_repositories):
             external_repository.handle.location_name,
             external_repository.name,
         )
-        if not repo_id in used:
+        if repo_id not in used:
             used.add(repo_id)
             repos.append(external_repository)
 
