@@ -1,11 +1,13 @@
-import graphene
-
 import dagster._check as check
+import graphene
 from dagster._core.execution.backfill import PartitionBackfill
 from dagster._core.storage.pipeline_run import RunsFilter
 from dagster._core.storage.tags import BACKFILL_ID_TAG
 
-from ..implementation.fetch_partition_sets import partition_statuses_from_run_partition_data
+from ..implementation.fetch_partition_sets import (
+    partition_status_counts_from_run_partition_data,
+    partition_statuses_from_run_partition_data,
+)
 from .asset_key import GrapheneAssetKey
 from .errors import (
     GrapheneInvalidOutputError,
@@ -113,6 +115,9 @@ class GraphenePartitionBackfill(graphene.ObjectType):
     partitionStatuses = graphene.NonNull(
         "dagster_graphql.schema.partition_sets.GraphenePartitionStatuses"
     )
+    partitionStatusCounts = non_null_list(
+        "dagster_graphql.schema.partition_sets.GraphenePartitionStatusCounts"
+    )
 
     def __init__(self, backfill_job):
         self._backfill_job = check.opt_inst_param(backfill_job, "backfill_job", PartitionBackfill)
@@ -223,6 +228,12 @@ class GraphenePartitionBackfill(graphene.ObjectType):
             backfill_id=self._backfill_job.backfill_id,
         )
 
+    def resolve_partitionStatusCounts(self, graphene_info):
+        partition_run_data = self._get_partition_run_data(graphene_info)
+        return partition_status_counts_from_run_partition_data(
+            partition_run_data, self._backfill_job.get_partition_names(graphene_info.context)
+        )
+
     def resolve_error(self, _):
         if self._backfill_job.error:
             return GraphenePythonError(self._backfill_job.error)
