@@ -1,5 +1,4 @@
 import graphene
-
 from dagster._core.storage.compute_log_manager import ComputeIOType
 
 from ...implementation.execution import gen_captured_log_data, gen_compute_logs, gen_events_for_run
@@ -20,7 +19,10 @@ class GrapheneDagitSubscription(graphene.ObjectType):
         runId=graphene.Argument(graphene.NonNull(graphene.ID)),
         cursor=graphene.Argument(
             graphene.String,
-            description="A cursor retrieved from the API. Pass 'HEAD' to stream from the current event onward.",
+            description=(
+                "A cursor retrieved from the API. Pass 'HEAD' to stream from the current event"
+                " onward."
+            ),
         ),
         description="Retrieve real-time event logs after applying a filter on run id and cursor.",
     )
@@ -31,7 +33,10 @@ class GrapheneDagitSubscription(graphene.ObjectType):
         stepKey=graphene.Argument(graphene.NonNull(graphene.String)),
         ioType=graphene.Argument(graphene.NonNull(GrapheneComputeIOType)),
         cursor=graphene.Argument(graphene.String),
-        description="Retrieve real-time compute logs after applying a filter on run id, step name, log type, and cursor.",
+        description=(
+            "Retrieve real-time compute logs after applying a filter on run id, step name, log"
+            " type, and cursor."
+        ),
     )
 
     capturedLogs = graphene.Field(
@@ -43,7 +48,9 @@ class GrapheneDagitSubscription(graphene.ObjectType):
 
     locationStateChangeEvents = graphene.Field(
         graphene.NonNull(GrapheneLocationStateChangeSubscription),
-        description="Retrieve real-time events when a location in the workspace undergoes a state change.",
+        description=(
+            "Retrieve real-time events when a location in the workspace undergoes a state change."
+        ),
     )
 
     def subscribe_pipelineRunLogs(self, graphene_info, runId, cursor=None):
